package com.me.pacman.level;

import com.badlogic.gdx.graphics.g2d.TextureRegion;
import com.me.pacman.PacDude;

public class Level {

    private PacDude game;

    private TextureRegion pellet;
    private TextureRegion powerPellet;

    // Grid of components, [rows][columns]
    public LevelTile[][] components;


    public Level(PacDude game, String level) {
        this.game = game;

        pellet = game.assets.level[0][6];
        powerPellet = game.assets.level[0][7];

        LevelLoader loader = new LevelLoader(level);
        components = loader.loadLevel();
    }

    public LevelTile getComponent(int x, int y) {
        return components[y][x];
    }

    public LevelTile getComponent(float x, float y) {
        return getComponent((int) x, (int) y);
    }

    public void setComponent(int x, int y, LevelTile component) {
        components[y][x] = component;
    }

    public void render(int offsetX, int offsetY) {
        for (int i = 0; i < components.length; i++) {
            LevelTile[] row = components[i];
            for (int j = 0; j < row.length; j++) {
                LevelTile component = row[j];
                TextureRegion sprite;
                switch (component) {
                    case PELLET:
                        sprite = pellet;
                        break;
                    case POWER_PELLET:
                        sprite = powerPellet;
                        break;
                    default:
                        continue;
                }
                game.batch.draw(sprite, (j * 8) + offsetX, (i * 8) + offsetY);
            }
        }
    }

}
